<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>AboutForm</name>
    <message>
        <location filename="../ui/aboutform.ui" line="14"/>
        <source>About SomePlayer</source>
        <translation>О SomePlayer</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="103"/>
        <source>&lt;b&gt;SomePlayer 1.5.2&lt;/b&gt; </source>
        <translation>&lt;b&gt;SomePlayer 1.5.2&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="128"/>
        <source>&lt;p align=&quot;center&quot;&gt;Alternative music player for Maemo 5. It includes media-library, playlists, equalizer, and supports many other things.&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;center&quot;&gt;Альтернативный аудиоплеер для Maemo 5. Поддерживает медиабиблиотеку, плейлисты, эквалайзер и много других вещей.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="151"/>
        <source>&lt;p align=&quot;center&quot;&gt;Licensed under GPLv2&lt;br&gt;
By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b&gt;SomePlayer&lt;/b&gt; tries to be a full replacement of standard music player for Maemo5 with many other features such as equalizer, custom playlists, smarter random mode, more flexible media-library and improved algorithm for cover searching.&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;center&quot;&gt;Лицензирован под GPLv2&lt;br&gt;
Автор: Николай Тищенко (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b&gt;SomePlayer&lt;/b&gt; это попытка полностью заменить стандартный аудиоплеер в Maemo 5, привнеся поддержку многих других вещей: эквалайзер, пользовательские плейлисты, составленные из файлов, продвинутый случайный режим, более гибкая медиабиблиотека и продвинутый алгоритм поиска обложек для альбомов.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="175"/>
        <source>&lt;p align=&quot;center&quot;&gt;
&lt;b&gt;Thanks to:&lt;/b&gt;&lt;br&gt;
MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemoworld.ru)&lt;br /&gt;lknfox (maemoworld.ru)&lt;br /&gt;fab (maemoworld.ru)&lt;br /&gt;Pantera1989m (github.com)&lt;br /&gt;willkr (maemo.org)&lt;br /&gt;and other people who tested this player and helped in development&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;center&quot;&gt;
&lt;b&gt;Спасибо:&lt;/b&gt;&lt;br&gt;
MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemoworld.ru)&lt;br /&gt;lknfox (maemoworld.ru)&lt;br /&gt;fab (maemoworld.ru)&lt;br /&gt;Pantera1989m (github.com)&lt;br /&gt;willkr (maemo.org)&lt;br /&gt;и всем остальным кто участвовал в разработке и тестировании плеера&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="189"/>
        <source>Online help</source>
        <translation>Онлайн справка</translation>
    </message>
    <message>
        <location filename="../ui/aboutform.ui" line="196"/>
        <source>Donate</source>
        <translation>Donate</translation>
    </message>
</context>
<context>
    <name>DirectoryView</name>
    <message>
        <location filename="../ui/directoryview.ui" line="14"/>
        <source>Directories</source>
        <translation>Каталоги</translation>
    </message>
    <message>
        <location filename="../directoryview.cpp" line="88"/>
        <source>Audioclips</source>
        <translation>Аудиоклипы</translation>
    </message>
    <message>
        <location filename="../directoryview.cpp" line="309"/>
        <source>Inner memory</source>
        <translation>Внутренняя память</translation>
    </message>
    <message>
        <location filename="../directoryview.cpp" line="311"/>
        <source>Memory card</source>
        <translation>Карта памяти</translation>
    </message>
</context>
<context>
    <name>EditTagsDialog</name>
    <message>
        <location filename="../ui/edittagsdialog.ui" line="14"/>
        <source>Edit tags</source>
        <translation>Редактировать теги</translation>
    </message>
    <message>
        <location filename="../ui/edittagsdialog.ui" line="22"/>
        <source>Artist:</source>
        <translation>Исполнитель:</translation>
    </message>
    <message>
        <location filename="../ui/edittagsdialog.ui" line="32"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../ui/edittagsdialog.ui" line="42"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
</context>
<context>
    <name>EqualizerDialog</name>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="14"/>
        <source>Equalizer</source>
        <translation>Эквалайзер</translation>
    </message>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="39"/>
        <source>+12dB</source>
        <translation>+12dB</translation>
    </message>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="59"/>
        <source>-12dB</source>
        <translation>-12dB</translation>
    </message>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="219"/>
        <source>Enable</source>
        <translation>Включен</translation>
    </message>
    <message>
        <location filename="../ui/equalizerdialog.ui" line="263"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
</context>
<context>
    <name>FmtxSettingsDialog</name>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="14"/>
        <source>FMTX Settings</source>
        <translation>Настройки FMTX</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="23"/>
        <source>Frequency:</source>
        <translation>Частота:</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="39"/>
        <source>88</source>
        <translation>88</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="47"/>
        <source>89</source>
        <translation>89</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="55"/>
        <location filename="../ui/fmtxsettingsdialog.ui" line="353"/>
        <source>90</source>
        <translation>90</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="63"/>
        <source>91</source>
        <translation>91</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="71"/>
        <source>92</source>
        <translation>92</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="79"/>
        <source>93</source>
        <translation>93</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="87"/>
        <source>94</source>
        <translation>94</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="95"/>
        <location filename="../ui/fmtxsettingsdialog.ui" line="361"/>
        <source>95</source>
        <translation>95</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="103"/>
        <source>96</source>
        <translation>96</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="111"/>
        <source>97</source>
        <translation>97</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="119"/>
        <source>98</source>
        <translation>98</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="127"/>
        <source>99</source>
        <translation>99</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="135"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="143"/>
        <source>101</source>
        <translation>101</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="151"/>
        <source>102</source>
        <translation>102</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="159"/>
        <source>103</source>
        <translation>103</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="167"/>
        <source>104</source>
        <translation>104</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="175"/>
        <source>105</source>
        <translation>105</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="183"/>
        <source>106</source>
        <translation>106</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="191"/>
        <source>107</source>
        <translation>107</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="209"/>
        <source>00</source>
        <translation>00</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="217"/>
        <source>05</source>
        <translation>05</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="225"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="233"/>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="241"/>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="249"/>
        <source>25</source>
        <translation>25</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="257"/>
        <source>30</source>
        <translation>30</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="265"/>
        <source>35</source>
        <translation>35</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="273"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="281"/>
        <source>45</source>
        <translation>45</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="289"/>
        <source>50</source>
        <translation>50</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="297"/>
        <source>55</source>
        <translation>55</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="305"/>
        <source>60</source>
        <translation>60</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="313"/>
        <source>65</source>
        <translation>65</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="321"/>
        <source>70</source>
        <translation>70</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="329"/>
        <source>75</source>
        <translation>75</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="337"/>
        <source>80</source>
        <translation>80</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="345"/>
        <source>85</source>
        <translation>85</translation>
    </message>
    <message>
        <location filename="../ui/fmtxsettingsdialog.ui" line="384"/>
        <source>Station:</source>
        <translation>Станция:</translation>
    </message>
</context>
<context>
    <name>LibraryForm</name>
    <message>
        <location filename="../ui/libraryform.ui" line="14"/>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <location filename="../ui/libraryform.ui" line="343"/>
        <location filename="../libraryform.cpp" line="174"/>
        <source>Artists</source>
        <translation>Исполнители</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="201"/>
        <source>Dynamic playlists</source>
        <translation>Динамические плейлисты</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="226"/>
        <location filename="../libraryform.cpp" line="415"/>
        <source>Albums by &quot;%1&quot;</source>
        <translation>Альбомы &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="239"/>
        <source>Tracks from &quot;%1&quot; by &quot;%2&quot;</source>
        <translation>Треки из &quot;%1&quot; от &quot;%2&quot;</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="249"/>
        <source>All tracks by &quot;%1&quot;</source>
        <translation>Все треки &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="267"/>
        <source>Tracks in playlist &quot;%1&quot;</source>
        <translation>Треки в плейлисте &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="439"/>
        <source>Playlists</source>
        <translation>Плейлисты</translation>
    </message>
    <message>
        <location filename="../libraryform.cpp" line="817"/>
        <source>Search in library</source>
        <translation>Поиск в библиотеке</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <source>SomePlayer</source>
        <translation>SomePlayer</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="40"/>
        <source>Main</source>
        <translation>Основное</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="47"/>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="53"/>
        <source>Tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="60"/>
        <source>Player</source>
        <translation>Плеер</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="66"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="78"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="83"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="88"/>
        <source>Manage library</source>
        <translation>Управление библиотекой</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="93"/>
        <source>Equalizer</source>
        <translation>Эквалайзер</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="98"/>
        <source>Set timer</source>
        <translation>Установить таймер</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="103"/>
        <source>Save playlist</source>
        <translation>Сохранить плейлист</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="106"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="111"/>
        <source>Online help</source>
        <translation>Онлайн справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Clear playlist?</source>
        <translation>Очистить плейлист?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="272"/>
        <source>Music off: </source>
        <translation>Отключение: </translation>
    </message>
</context>
<context>
    <name>ManageLibraryForm</name>
    <message>
        <location filename="../ui/managelibraryform.ui" line="14"/>
        <source>Manage library</source>
        <translation>Управление библиотекой</translation>
    </message>
    <message>
        <location filename="../ui/managelibraryform.ui" line="231"/>
        <source>Added directories:</source>
        <translation>Добавленные директории:</translation>
    </message>
    <message>
        <location filename="../ui/managelibraryform.ui" line="295"/>
        <source>0 artitst</source>
        <translation>0 исполнителей</translation>
    </message>
    <message>
        <location filename="../ui/managelibraryform.ui" line="302"/>
        <source>0 albums</source>
        <translation>0 альбомов</translation>
    </message>
    <message>
        <location filename="../ui/managelibraryform.ui" line="312"/>
        <source>0 tracks</source>
        <translation>0 треков</translation>
    </message>
    <message>
        <location filename="../managelibraryform.cpp" line="66"/>
        <source>Select directory</source>
        <translation>Выбрать директорию</translation>
    </message>
    <message>
        <location filename="../managelibraryform.cpp" line="126"/>
        <source>Delete selected directories?</source>
        <translation>Удалить выбранные директории?</translation>
    </message>
    <message>
        <location filename="../managelibraryform.cpp" line="145"/>
        <source>Update selected directories? It may takes several minutes</source>
        <translation>Обновить выбранные директории? Это может занять несколько минут</translation>
    </message>
    <message>
        <location filename="../managelibraryform.cpp" line="165"/>
        <source>Update all library? It may takes a long time</source>
        <translation>Обновить всю библиотеку? Это может занять длительное время</translation>
    </message>
</context>
<context>
    <name>PlayerForm</name>
    <message>
        <location filename="../ui/playerform.ui" line="14"/>
        <source>SomePlayer</source>
        <translation>SomePlayer</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="124"/>
        <source>Music off: 00:00:00</source>
        <translation>Выключение: 00:00:00</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="472"/>
        <source>0/0</source>
        <translation>0/0</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="508"/>
        <source>&lt;h3&gt;Title&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Название&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="538"/>
        <location filename="../ui/playerform.ui" line="558"/>
        <source>00:00</source>
        <translation>00:00</translation>
    </message>
    <message>
        <location filename="../ui/playerform.ui" line="634"/>
        <source>&lt;b&gt;Artist&lt;/b&gt;&lt;br/&gt;album</source>
        <translation>&lt;b&gt;Исполнитель&lt;/b&gt;&lt;br/&gt;альбом</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="91"/>
        <location filename="../playerform.cpp" line="771"/>
        <source>Clear playlist</source>
        <translation>Очистить плейлист</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="92"/>
        <location filename="../playerform.cpp" line="772"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="93"/>
        <location filename="../playerform.cpp" line="239"/>
        <location filename="../playerform.cpp" line="279"/>
        <location filename="../playerform.cpp" line="773"/>
        <source>Add to favorites</source>
        <translation>В избранное</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="94"/>
        <location filename="../playerform.cpp" line="774"/>
        <source>Enqueue</source>
        <translation>В очередь</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="95"/>
        <location filename="../playerform.cpp" line="775"/>
        <source>Add to playlists</source>
        <translation>Добавить в плейлисты</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="96"/>
        <location filename="../playerform.cpp" line="776"/>
        <source>Edit tags</source>
        <translation>Редактировать теги</translation>
    </message>
    <message>
        <location filename="../playerform.cpp" line="239"/>
        <location filename="../playerform.cpp" line="279"/>
        <source>Remove from favorites</source>
        <translation>Удалить из избранного</translation>
    </message>
</context>
<context>
    <name>PlaylistDialog</name>
    <message>
        <location filename="../ui/playlistdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
</context>
<context>
    <name>PlaylistSortForm</name>
    <message>
        <location filename="../ui/playlistsortform.ui" line="14"/>
        <source>Sorting</source>
        <translation>Сортировка</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libraryform.cpp" line="65"/>
        <source>All tracks</source>
        <translation>Все треки</translation>
    </message>
</context>
<context>
    <name>SavePlaylistDialog</name>
    <message>
        <location filename="../ui/saveplaylistdialog.ui" line="14"/>
        <source>Save playlist</source>
        <translation>Сохранить плейлист</translation>
    </message>
    <message>
        <location filename="../ui/saveplaylistdialog.ui" line="26"/>
        <source>Existed playlists:</source>
        <translation>Плейлисты:</translation>
    </message>
    <message>
        <location filename="../ui/saveplaylistdialog.ui" line="39"/>
        <source>New: </source>
        <translation>Новый:</translation>
    </message>
</context>
<context>
    <name>SettingsForm</name>
    <message>
        <location filename="../ui/settingsform.ui" line="14"/>
        <location filename="../ui/settingsform.ui" line="713"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="28"/>
        <source>UI</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="41"/>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="103"/>
        <source>Icons theme:</source>
        <translation>Тема иконок:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="129"/>
        <source>White</source>
        <translation>Белые</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="136"/>
        <source>Black</source>
        <translation>Чёрные</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="148"/>
        <source>Use gradient in portrait mode:</source>
        <translation>Градиент в портретном режиме:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="174"/>
        <location filename="../ui/settingsform.ui" line="530"/>
        <location filename="../ui/settingsform.ui" line="617"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="181"/>
        <location filename="../ui/settingsform.ui" line="537"/>
        <location filename="../ui/settingsform.ui" line="624"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="193"/>
        <source>Active track color:</source>
        <translation>Цвет текущего трека:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="222"/>
        <source>blue</source>
        <translation>голубой</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="232"/>
        <source>magenta</source>
        <translation>фиолетовый</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="242"/>
        <source>red</source>
        <translation>красный</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="252"/>
        <source>yellow</source>
        <translation>жёлтый</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="262"/>
        <source>white</source>
        <translation>белый</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="272"/>
        <source>black</source>
        <translation>чёрный</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="282"/>
        <source>light</source>
        <translation>светлый</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="292"/>
        <source>dark</source>
        <translation>тёмный</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="396"/>
        <source>Chinese</source>
        <translation>Китайский</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="459"/>
        <source>Sort album:</source>
        <translation>Сортировка альбомов:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="485"/>
        <source>Alphabetical</source>
        <translation>По алфавиту</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="492"/>
        <source>By date</source>
        <translation>По дате</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="636"/>
        <source>Use hardware keys</source>
        <translation>Аппаратные кнопки</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="657"/>
        <source>Zoom keys control:</source>
        <translation>«Качелька» управляет:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="666"/>
        <source>Volume</source>
        <translation>Звуком</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="673"/>
        <source>Tracks</source>
        <translation>Треками</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="685"/>
        <source>Use FMTX</source>
        <translation>Включить FMTX</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="304"/>
        <source>Orientation:</source>
        <translation>Ориентация:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="54"/>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="330"/>
        <source>Landscape</source>
        <translation>Ландшафтный</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="337"/>
        <source>Portrait</source>
        <translation>Портретный</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="344"/>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="504"/>
        <source>Show track lenght in library view:</source>
        <translation>Показывать длину трека:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="356"/>
        <source>Language:</source>
        <translation>Язык:</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="382"/>
        <source>English</source>
        <translation>Английский</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="389"/>
        <source>Russian</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="../ui/settingsform.ui" line="597"/>
        <source>Pause when headphones unplugged:</source>
        <translation>Пауза при отключении наушников:</translation>
    </message>
</context>
<context>
    <name>TimerDialog</name>
    <message>
        <location filename="../ui/timerdialog.ui" line="14"/>
        <source>Set timer</source>
        <translation>Установить таймер</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="24"/>
        <source>Hours</source>
        <translation>Часы</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="32"/>
        <location filename="../ui/timerdialog.ui" line="158"/>
        <location filename="../ui/timerdialog.ui" line="660"/>
        <source>00</source>
        <translation>00</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="40"/>
        <location filename="../ui/timerdialog.ui" line="166"/>
        <location filename="../ui/timerdialog.ui" line="668"/>
        <source>01</source>
        <translation>01</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="48"/>
        <location filename="../ui/timerdialog.ui" line="174"/>
        <location filename="../ui/timerdialog.ui" line="676"/>
        <source>02</source>
        <translation>02</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="56"/>
        <location filename="../ui/timerdialog.ui" line="182"/>
        <location filename="../ui/timerdialog.ui" line="684"/>
        <source>03</source>
        <translation>03</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="64"/>
        <location filename="../ui/timerdialog.ui" line="190"/>
        <location filename="../ui/timerdialog.ui" line="692"/>
        <source>04</source>
        <translation>04</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="72"/>
        <location filename="../ui/timerdialog.ui" line="198"/>
        <location filename="../ui/timerdialog.ui" line="700"/>
        <source>05</source>
        <translation>05</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="80"/>
        <location filename="../ui/timerdialog.ui" line="206"/>
        <location filename="../ui/timerdialog.ui" line="708"/>
        <source>06</source>
        <translation>06</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="88"/>
        <location filename="../ui/timerdialog.ui" line="214"/>
        <location filename="../ui/timerdialog.ui" line="716"/>
        <source>07</source>
        <translation>07</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="96"/>
        <location filename="../ui/timerdialog.ui" line="222"/>
        <location filename="../ui/timerdialog.ui" line="724"/>
        <source>08</source>
        <translation>08</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="104"/>
        <location filename="../ui/timerdialog.ui" line="230"/>
        <location filename="../ui/timerdialog.ui" line="732"/>
        <source>09</source>
        <translation>09</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="112"/>
        <location filename="../ui/timerdialog.ui" line="238"/>
        <location filename="../ui/timerdialog.ui" line="740"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="120"/>
        <location filename="../ui/timerdialog.ui" line="246"/>
        <location filename="../ui/timerdialog.ui" line="748"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="128"/>
        <location filename="../ui/timerdialog.ui" line="254"/>
        <location filename="../ui/timerdialog.ui" line="756"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="141"/>
        <location filename="../ui/timerdialog.ui" line="643"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="150"/>
        <source>Minutes</source>
        <translation>Минуты</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="262"/>
        <location filename="../ui/timerdialog.ui" line="764"/>
        <source>13</source>
        <translation>13</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="270"/>
        <location filename="../ui/timerdialog.ui" line="772"/>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="278"/>
        <location filename="../ui/timerdialog.ui" line="780"/>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="286"/>
        <location filename="../ui/timerdialog.ui" line="788"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="294"/>
        <location filename="../ui/timerdialog.ui" line="796"/>
        <source>17</source>
        <translation>17</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="302"/>
        <location filename="../ui/timerdialog.ui" line="804"/>
        <source>18</source>
        <translation>18</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="310"/>
        <location filename="../ui/timerdialog.ui" line="812"/>
        <source>19</source>
        <translation>19</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="318"/>
        <location filename="../ui/timerdialog.ui" line="820"/>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="326"/>
        <location filename="../ui/timerdialog.ui" line="828"/>
        <source>21</source>
        <translation>21</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="334"/>
        <location filename="../ui/timerdialog.ui" line="836"/>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="342"/>
        <location filename="../ui/timerdialog.ui" line="844"/>
        <source>23</source>
        <translation>23</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="350"/>
        <location filename="../ui/timerdialog.ui" line="852"/>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="358"/>
        <location filename="../ui/timerdialog.ui" line="860"/>
        <source>25</source>
        <translation>25</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="366"/>
        <location filename="../ui/timerdialog.ui" line="868"/>
        <source>26</source>
        <translation>26</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="374"/>
        <location filename="../ui/timerdialog.ui" line="876"/>
        <source>27</source>
        <translation>27</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="382"/>
        <location filename="../ui/timerdialog.ui" line="884"/>
        <source>28</source>
        <translation>28</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="390"/>
        <location filename="../ui/timerdialog.ui" line="892"/>
        <source>29</source>
        <translation>29</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="398"/>
        <location filename="../ui/timerdialog.ui" line="900"/>
        <source>30</source>
        <translation>30</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="406"/>
        <location filename="../ui/timerdialog.ui" line="908"/>
        <source>31</source>
        <translation>31</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="414"/>
        <location filename="../ui/timerdialog.ui" line="916"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="422"/>
        <location filename="../ui/timerdialog.ui" line="924"/>
        <source>33</source>
        <translation>33</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="430"/>
        <location filename="../ui/timerdialog.ui" line="932"/>
        <source>34</source>
        <translation>34</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="438"/>
        <location filename="../ui/timerdialog.ui" line="940"/>
        <source>35</source>
        <translation>35</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="446"/>
        <location filename="../ui/timerdialog.ui" line="948"/>
        <source>36</source>
        <translation>36</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="454"/>
        <location filename="../ui/timerdialog.ui" line="956"/>
        <source>37</source>
        <translation>37</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="462"/>
        <location filename="../ui/timerdialog.ui" line="964"/>
        <source>38</source>
        <translation>38</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="478"/>
        <location filename="../ui/timerdialog.ui" line="980"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="486"/>
        <location filename="../ui/timerdialog.ui" line="988"/>
        <source>41</source>
        <translation>41</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="494"/>
        <location filename="../ui/timerdialog.ui" line="996"/>
        <source>42</source>
        <translation>42</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="502"/>
        <location filename="../ui/timerdialog.ui" line="1004"/>
        <source>43</source>
        <translation>43</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="510"/>
        <location filename="../ui/timerdialog.ui" line="1012"/>
        <source>44</source>
        <translation>44</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="518"/>
        <location filename="../ui/timerdialog.ui" line="1020"/>
        <source>45</source>
        <translation>45</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="526"/>
        <location filename="../ui/timerdialog.ui" line="1028"/>
        <source>46</source>
        <translation>46</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="534"/>
        <location filename="../ui/timerdialog.ui" line="1036"/>
        <source>47</source>
        <translation>47</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="542"/>
        <location filename="../ui/timerdialog.ui" line="1044"/>
        <source>48</source>
        <translation>48</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="550"/>
        <location filename="../ui/timerdialog.ui" line="1052"/>
        <source>49</source>
        <translation>49</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="558"/>
        <location filename="../ui/timerdialog.ui" line="1060"/>
        <source>50</source>
        <translation>50</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="566"/>
        <location filename="../ui/timerdialog.ui" line="1068"/>
        <source>51</source>
        <translation>51</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="574"/>
        <location filename="../ui/timerdialog.ui" line="1076"/>
        <source>52</source>
        <translation>52</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="582"/>
        <location filename="../ui/timerdialog.ui" line="1084"/>
        <source>53</source>
        <translation>53</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="590"/>
        <location filename="../ui/timerdialog.ui" line="1092"/>
        <source>54</source>
        <translation>54</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="598"/>
        <location filename="../ui/timerdialog.ui" line="1100"/>
        <source>55</source>
        <translation>55</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="606"/>
        <location filename="../ui/timerdialog.ui" line="1108"/>
        <source>56</source>
        <translation>56</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="614"/>
        <location filename="../ui/timerdialog.ui" line="1116"/>
        <source>57</source>
        <translation>57</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="622"/>
        <location filename="../ui/timerdialog.ui" line="1124"/>
        <source>58</source>
        <translation>58</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="630"/>
        <location filename="../ui/timerdialog.ui" line="1132"/>
        <source>59</source>
        <translation>59</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="652"/>
        <source>Seconds</source>
        <translation>Секунды</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="470"/>
        <location filename="../ui/timerdialog.ui" line="972"/>
        <source>39</source>
        <translation>39</translation>
    </message>
    <message>
        <location filename="../ui/timerdialog.ui" line="1153"/>
        <source>Disable</source>
        <translation>Выключить</translation>
    </message>
</context>
<context>
    <name>ToolsWidget</name>
    <message>
        <location filename="../ui/toolswidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
</context>
</TS>
